OPERATOR = 'operator'
VARIABLE = 'variableName'
VARIABLE_TYPE = 'variableType'
VALUE = 'value'
NODE = 'node'
CONDITION = 'condition'
CHILDREN = 'children'

#  =======
# | TYPES |
#  =======

STRING_TYPE = 'string'

OBJECT_TYPE = 'object'

NUMBER_TYPE = 'number'


TO_PYTHON_TYPE = {
    STRING_TYPE: 'str',
    NUMBER_TYPE: 'float',
    OBJECT_TYPE: '',
}
